@@ -149,20 +149,19 @@ pub mod binary {
                 }
                 (Err(_), Err(_), Ok(after)) => {
                     hit += 1;
-                    assert_eq!(after.to_binary(), i)
+                    assert_eq!(after.to_binary(), i);
                 }
                 (Err(_), Ok(normal), Err(_)) => {
                     hit += 1;
-                    assert_eq!(normal.to_binary(), i)
+                    assert_eq!(normal.to_binary(), i);
                 }
                 (Ok(inf), Err(_), Err(_)) => {
                     hit += 1;
-                    assert_eq!(inf.to_binary(), i)
+                    assert_eq!(inf.to_binary(), i);
                 }
                 _ => panic!("Ambiguous mapping detected!!!!!"),
             }
         }
-        #[allow(clippy::cast_lossless)]
         println!(
             "hit: {}, miss: {}, hit ratio: {}",
             hit,
@@ -355,7 +354,6 @@ pub mod binary {
             .to_binary()
         }
         fn from_binary(v: u32) -> Result<Self, &'static str> {
-            use std::convert::TryInto;
             let tag: u8 = ((v & (15 << 28)) >> 28).try_into().unwrap();
             if tag == 0
             /* NormalMove::NonTamMoveFromHopZuo */
@@ -458,7 +456,6 @@ pub mod binary {
     }
 
     fn to_7bit(c: absolute::Coord) -> u8 {
-        use std::convert::TryInto;
         let [row, col] = cetkaik_core::perspective::to_relative_coord(
             c,
             cetkaik_core::perspective::Perspective::IaIsDownAndPointsUpward,
@@ -527,14 +524,13 @@ pub mod binary {
             let second_dest: u32 = to_7bit_(self.second_dest).into();
             let tag = self.tag as u8;
             if tag > 15 {
-                panic!("tag too large")
+                panic!("tag too large");
             }
             let tag: u32 = tag.into();
             src | (step << 7) | (first_dest << 14) | (second_dest << 21) | (tag << 28)
         }
 
         fn from_binary(v: u32) -> Result<Self, &'static str> {
-            use std::convert::TryInto;
             let src: u8 = (v & 127).try_into().unwrap();
             let step: u8 = ((v & (127 << 7)) >> 7).try_into().unwrap();
             let first_dest: u8 = ((v & (127 << 14)) >> 14).try_into().unwrap();
